@@ -154,19 +154,19 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_PRINT_BARE_VALUE, 1);
 	netsnmp_ds_set_boolean(NETSNMP_DS_LIBRARY_ID, NETSNMP_DS_LIB_NUMERIC_TIMETICKS, 1);
 
-	session.securityEngineID = 0;
+	session.securityEngineID    = 0;
 	session.securityEngineIDLen = 0;
 
-	session.securityName = 0;
+	session.securityName    = 0;
 	session.securityNameLen = 0;
 
-	session.contextEngineID = 0;
+	session.contextEngineID    = 0;
 	session.contextEngineIDLen = 0;
 
-	session.contextName = 0;
+	session.contextName    = 0;
 	session.contextNameLen = 0;
 
-	session.contextEngineID = 0;
+	session.contextEngineID    = 0;
 	session.contextEngineIDLen = 0;
 
 	/* verify snmp version is accurate */
@@ -189,7 +189,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 	session.retries     = set.snmp_retries;
 	session.timeout     = (snmp_timeout * 1000); /* net-snmp likes microseconds */
 
-	SPINE_LOG_MEDIUM(("Device[%i] INFO: SNMP Device '%s' has a timeout of %ld (%d), with %d retries", host_id, hostnameport, session.timeout, snmp_timeout, session.retries));
+	SPINE_LOG_HIGH(("Device[%i] INFO: SNMP Device '%s' has a timeout of %ld (%d), with %d retries", host_id, hostnameport, session.timeout, snmp_timeout, session.retries));
 
 	if ((snmp_version == 2) || (snmp_version == 1)) {
 		session.community     = (unsigned char*) snmp_community;
@@ -292,6 +292,16 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 				SPINE_LOG(("SNMP: Error DES is no longer supported on this system"));
 				return 0;
 				#endif
+			} else if (strcmp(snmp_priv_protocol, "AES") == 0) {
+				#if defined(USM_PRIV_PROTO_AES_LEN)
+				session.securityPrivProto    = snmp_duplicate_objid(usmAESPrivProtocol, USM_PRIV_PROTO_AES_LEN);
+				session.securityPrivProtoLen = USM_PRIV_PROTO_AES_LEN;
+				session.securityPrivKeyLen   = USM_PRIV_KU_LEN;
+				session.securityLevel        = SNMP_SEC_LEVEL_AUTHPRIV;
+				#else
+				SPINE_LOG(("SNMP: Error AES is not supported in the Net-SNMP API, upgrade the Net-SNMP libraries."));
+				return 0;
+				#endif
 			} else if (strcmp(snmp_priv_protocol, "AES128") == 0) {
 				#if defined(USM_PRIV_PROTO_AES_LEN)
 				session.securityPrivProto    = snmp_duplicate_objid(usmAESPrivProtocol, USM_PRIV_PROTO_AES_LEN);
@@ -308,7 +318,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(USM_CREATE_USER_PRIV_AES192)
 				session.securityPrivProto    = snmp_duplicate_objid(usmAES192PrivProtocol, OID_LENGTH(usmAES192PrivProtocol));
 				session.securityPrivProtoLen = OID_LENGTH(usmAES192PrivProtocol);
-				session.securityPrivKeyLen   = BYTESIZE(SNMP_TRANS_PRIVLEN_AES192);
+				session.securityPrivKeyLen   = SNMP_TRANS_PRIVLEN_AES192;
 				session.securityLevel        = SNMP_SEC_LEVEL_AUTHPRIV;
 				#else
 				SPINE_LOG(("SNMP: Error AES-192 is not supported in the Net-SNMP API, upgrade the Net-SNMP libraries."));
@@ -318,15 +328,36 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(USM_CREATE_USER_PRIV_AES256)
 				session.securityPrivProto    = snmp_duplicate_objid(usmAES256PrivProtocol, OID_LENGTH(usmAES256PrivProtocol));
 				session.securityPrivProtoLen = OID_LENGTH(usmAES256PrivProtocol);
-				session.securityPrivKeyLen   = BYTESIZE(SNMP_TRANS_PRIVLEN_AES256);
+				session.securityPrivKeyLen   = SNMP_TRANS_PRIVLEN_AES256;
 				session.securityLevel        = SNMP_SEC_LEVEL_AUTHPRIV;
 				#else
 				SPINE_LOG(("SNMP: Error AES-256 is not supported in the Net-SNMP API, upgrade the Net-SNMP libraries."));
 				return 0;
 				#endif
+			} else if(strcmp(snmp_priv_protocol, "AES192C") == 0) {
+				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(USM_CREATE_USER_PRIV_AES192_CISCO)
+				session.securityPrivProto    = snmp_duplicate_objid(usmAES192CiscoPrivProtocol, OID_LENGTH(usmAES192CiscoPrivProtocol));
+				session.securityPrivProtoLen = OID_LENGTH(usmAES192CiscoPrivProtocol);
+				session.securityPrivKeyLen   = SNMP_TRANS_PRIVLEN_AES192;
+				session.securityLevel        = SNMP_SEC_LEVEL_AUTHPRIV;
+				#else
+				SPINE_LOG(("SNMP: Error AES192C is not supported in the Net-SNMP API, upgrade the Net-SNMP libraries."));
+				return 0;
+				#endif
+			} else if(strcmp(snmp_priv_protocol, "AES256C") == 0) {
+				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(USM_CREATE_USER_PRIV_AES256_CISCO)
+				session.securityPrivProto    = snmp_duplicate_objid(usmAES256CiscoPrivProtocol, OID_LENGTH(usmAES256CiscoPrivProtocol));
+				session.securityPrivProtoLen = OID_LENGTH(usmAES256CiscoPrivProtocol);
+				session.securityPrivKeyLen   = SNMP_TRANS_PRIVLEN_AES256;
+				session.securityLevel        = SNMP_SEC_LEVEL_AUTHPRIV;
+				#else
+				SPINE_LOG(("SNMP: Error AES256C is not supported in the Net-SNMP API, upgrade the Net-SNMP libraries."));
+				return 0;
+				#endif
 			}
-
+			
 			/* set the privacy key to the hashed version. */
+			SPINE_LOG_MEDIUM(("SNMP: Using privacy protocol(len): %s(%d)", snmp_priv_protocol, session.securityPrivKeyLen));
 			if (generate_Ku(session.securityAuthProto,
 				session.securityAuthProtoLen,
 				(u_char *) snmp_priv_passphrase,
@@ -458,7 +489,13 @@ char *snmp_get_base(host_t *current_host, char *snmp_oid, bool should_fail) {
 				} else if (vars->type == SNMP_NOSUCHINSTANCE) {
 					SET_UNDEFINED(result_string);
 					status = STAT_ERROR;
-					SPINE_LOG_HIGH(("ERROR: No such Instance for oid '%s' for Device[%d] with Status[%d]",  snmp_oid, current_host->id, status));
+
+					// We will ignore the new OID error
+					if (!strstr(snmp_oid, ".1.3.6.1.6.3.10.2.1.3.0")) {
+						SPINE_LOG_HIGH(("WARNING: No such Instance for oid '%s' for Device[%d] with Status[%d]",  snmp_oid, current_host->id, status));
+					} else {
+						SPINE_LOG_DEBUG(("NOTE: Legacy SNMP agent found!  No per second Uptime oid found '%s' for Device[%d] with Status[%d]",  snmp_oid, current_host->id, status));
+					}
 				} else if (vars->type == SNMP_ENDOFMIBVIEW) {
 					SET_UNDEFINED(result_string);
 					status = STAT_ERROR;
@@ -481,7 +518,13 @@ char *snmp_get_base(host_t *current_host, char *snmp_oid, bool should_fail) {
 			} else if (vars->type == SNMP_NOSUCHINSTANCE) {
 				SET_UNDEFINED(result_string);
 				status = STAT_ERROR;
-				SPINE_LOG_HIGH(("ERROR: No such Instance for oid '%s' for Device[%d] with Status[%d]",  snmp_oid, current_host->id, status));
+
+				// We will ignore the new OID error
+				if (!strstr(snmp_oid, ".1.3.6.1.6.3.10.2.1.3.0")) {
+					SPINE_LOG_HIGH(("WARNING: No such Instance for oid '%s' for Device[%d] with Status[%d]",  snmp_oid, current_host->id, status));
+				} else {
+					SPINE_LOG_DEBUG(("NOTE: Per second level uptime oid missing oid '%s' for Device[%d] with Status[%d]",  snmp_oid, current_host->id, status));
+				}
 			} else if (vars->type == SNMP_ENDOFMIBVIEW) {
 				SET_UNDEFINED(result_string);
 				status = STAT_ERROR;
@@ -575,7 +618,7 @@ char *snmp_getnext(host_t *current_host, char *snmp_oid) {
 					if (vars != NULL) {
 						snprint_value(temp_result, RESULTS_BUFFER, vars->name, vars->name_length, vars);
 
-						snprint_asciistring(result_string, RESULTS_BUFFER, temp_result, strlen(temp_result));
+						snprint_asciistring(result_string, RESULTS_BUFFER, (unsigned char *)temp_result, strlen(temp_result));
 					} else {
 						SET_UNDEFINED(result_string);
 						status = STAT_ERROR;
