@@ -256,6 +256,10 @@ int main(int argc, char *argv[]) {
 	/* initialize icmp_avail */
 	set.icmp_avail = TRUE;
 
+	/* initialize number of threads */
+	set.threads = 1;
+	set.threads_set = FALSE;
+
 	/* detect and compensate for stdin/stderr ttys */
 	if (!isatty(fileno(stdout))) {
 		set.stdout_notty = TRUE;
@@ -322,6 +326,7 @@ int main(int argc, char *argv[]) {
 	set.logfile_processed = FALSE;
 	set.parent_fork       = SPINE_PARENT;
 	set.mode              = REMOTE_ONLINE;
+	set.has_device_0      = FALSE;
 
 	for (argv++; *argv; argv++) {
 		char	*arg = *argv;
@@ -357,6 +362,15 @@ int main(int argc, char *argv[]) {
 			set.poller_id = atoi(getarg(opt, &argv));
 		}
 
+		else if (STRMATCH(arg, "-t") || STRIMATCH(arg, "--threads")) {
+			set.threads = atoi(getarg(opt, &argv));
+			set.threads_set = TRUE;
+		}
+
+		else if (STRMATCH(arg, "-P") || STRIMATCH(arg, "--pingonly")) {
+			set.ping_only = TRUE;
+		}
+
 		else if (STRMATCH(arg, "-N") || STRIMATCH(arg, "--mode")) {
 			if (STRIMATCH(getarg(opt, &argv), "online")) {
 				set.mode = REMOTE_ONLINE;
@@ -435,6 +449,10 @@ int main(int argc, char *argv[]) {
 		}
 	}
 
+	if (set.ping_only) {
+		set.mibs = 0;
+	}
+
 	/* we attempt to support scripts better in cygwin */
 	#if defined(__CYGWIN__)
 	setenv("CYGWIN", "nodosfilewarning", 1);
@@ -532,6 +550,14 @@ int main(int argc, char *argv[]) {
 		mode = LOCAL;
 	}
 
+
+	/* check for device 0 items */
+	result = db_query(&mysql, LOCAL, "SELECT * FROM (SELECT COUNT(*) AS items FROM poller_item WHERE host_id = 0 AND poller_id = 1) AS rs WHERE rs.items > 0");
+	if (mysql_num_rows(result)) {
+		set.has_device_0 = TRUE;
+	}
+	db_free_result(result);
+
 	/* Since MySQL 5.7 the sql_mode defaults are too strict for cacti */
 	db_insert(&mysql, LOCAL, "SET SESSION sql_mode = (SELECT REPLACE(@@sql_mode,'NO_ZERO_DATE', ''))");
 	db_insert(&mysql, LOCAL, "SET SESSION sql_mode = (SELECT REPLACE(@@sql_mode,'ONLY_FULL_GROUP_BY', ''))");
@@ -560,6 +586,12 @@ int main(int argc, char *argv[]) {
 		}
 	}
 
+	if (set.has_device_0) {
+		SPINE_LOG_MEDIUM(("Device 0 Poller Items found.  Ensure that these entries are accurate"));
+	} else {
+		SPINE_LOG_MEDIUM(("No Device 0 Poller Items found."));
+	}
+
 	/* see if mysql is thread safe */
 	if (mysql_thread_safe()) {
 		if (set.log_level == POLLER_VERBOSITY_DEBUG) {
@@ -583,7 +615,7 @@ int main(int argc, char *argv[]) {
 	set.parent_fork = SPINE_PARENT;
 
 	/* initialize the script server */
-	if (set.php_required) {
+	if (set.php_required && !set.ping_only) {
 		php_init(PHP_INIT);
 		set.php_initialized    = TRUE;
 		set.php_current_server = 0;
@@ -603,7 +635,7 @@ int main(int argc, char *argv[]) {
 	db_free_result(result);
 
 	/* obtain the list of hosts to poll */
-	qp += sprintf(qp, "SELECT SQL_NO_CACHE id, device_threads, picount, picount/device_threads AS tppi FROM host INNER JOIN (SELECT host_id, COUNT(*) AS picount FROM poller_item GROUP BY host_id) AS pi ON host.id = pi.host_id");
+	qp += sprintf(qp, "SELECT SQL_NO_CACHE id, device_threads, picount, picount/device_threads AS tppi FROM host LEFT JOIN (SELECT host_id, COUNT(*) AS picount FROM poller_item GROUP BY host_id) AS pi ON host.id = pi.host_id");
 	qp += sprintf(qp, " WHERE disabled = ''");
 
 	if (!strlen(set.host_id_list)) {
@@ -621,7 +653,11 @@ int main(int argc, char *argv[]) {
 	result = db_query(&mysql, LOCAL, querybuf);
 
 	if (set.poller_id == 1) {
-		num_rows = mysql_num_rows(result) + 1; /* pollerid 1 takes care of not host based data sources */
+		if (set.has_device_0) {
+			num_rows = mysql_num_rows(result) + 1; /* pollerid 1 takes care of non host based data sources */
+		} else {
+			num_rows = mysql_num_rows(result); /* pollerid 1 takes care of non host based data sources */
+		}
 	} else {
 		num_rows = mysql_num_rows(result);
 	}
@@ -648,11 +684,13 @@ int main(int argc, char *argv[]) {
 	SOCK_STARTUP;
 
 	/* mark the spine process as started */
-	snprintf(querybuf, BIG_BUFSIZE, "INSERT INTO poller_time (poller_id, pid, start_time, end_time) VALUES (%i, %i, NOW(), '0000-00-00 00:00:00')", set.poller_id, getpid());
-	if (mode == REMOTE) {
-		db_insert(&mysqlr, REMOTE, querybuf);
-	} else {
-		db_insert(&mysql, LOCAL, querybuf);
+	if (!set.ping_only) {
+		snprintf(querybuf, BIG_BUFSIZE, "INSERT INTO poller_time (poller_id, pid, start_time, end_time) VALUES (%i, %i, NOW(), '0000-00-00 00:00:00')", set.poller_id, getpid());
+		if (mode == REMOTE) {
+			db_insert(&mysqlr, REMOTE, querybuf);
+		} else {
+			db_insert(&mysql, LOCAL, querybuf);
+		}
 	}
 
 	/* initialize threads and mutexes */
@@ -675,7 +713,7 @@ int main(int argc, char *argv[]) {
 	until_spec.tv_nsec = 0;
 
 	sem_getvalue(&available_threads, &a_threads_value);
-	SPINE_LOG_MEDIUM(("DEBUG: Initial Value of Available Threads is %i (%i outstanding)", a_threads_value, set.threads - a_threads_value));
+	SPINE_LOG_HIGH(("DEBUG: Initial Value of Available Threads is %i (%i outstanding)", a_threads_value, set.threads - a_threads_value));
 
 	/* tell fork processes that they are now active */
 	set.parent_fork = SPINE_FORK;
@@ -684,8 +722,8 @@ int main(int argc, char *argv[]) {
 	device_threads   = 1;
 	current_thread   = 0;
 
-	/* poller 0 always polls host 0 */
-	if (set.poller_id == 1) {
+	/* poller 1 always polls host 0 but only if it exists */
+	if (set.poller_id == 1 && set.has_device_0 == TRUE) {
 		host_id     = 0;
 		change_host = FALSE;
 	} else {
@@ -716,20 +754,24 @@ int main(int argc, char *argv[]) {
 		}
 
 		/* adjust device threads in cases where the host does not have sufficient data sources */
-		if (set.active_profiles != 1) {
-			snprintf(querybuf, BIG_BUFSIZE, "SELECT SQL_NO_CACHE COUNT(local_data_id) FROM poller_item WHERE host_id=%i AND rrd_next_step <=0", host_id);
+		if (!set.ping_only) {
+			if (set.active_profiles != 1) {
+				snprintf(querybuf, BIG_BUFSIZE, "SELECT SQL_NO_CACHE COUNT(local_data_id) FROM poller_item WHERE host_id=%i AND rrd_next_step <=0", host_id);
+			} else {
+				snprintf(querybuf, BIG_BUFSIZE, "SELECT SQL_NO_CACHE COUNT(local_data_id) FROM poller_item WHERE host_id=%i", host_id);
+			}
+
+			tresult   = db_query(&mysql, LOCAL, querybuf);
+			mysql_row = mysql_fetch_row(tresult);
+
+			total_items = atoi(mysql_row[0]);
+			db_free_result(tresult);
+
+			if (total_items && total_items < device_threads) {
+				device_threads = total_items;
+			}
 		} else {
-			snprintf(querybuf, BIG_BUFSIZE, "SELECT SQL_NO_CACHE COUNT(local_data_id) FROM poller_item WHERE host_id=%i", host_id);
-		}
-
-		tresult   = db_query(&mysql, LOCAL, querybuf);
-		mysql_row = mysql_fetch_row(tresult);
-
-		total_items = atoi(mysql_row[0]);
-		db_free_result(tresult);
-
-		if (total_items && total_items < device_threads) {
-			device_threads = total_items;
+			device_threads = 1;
 		}
 
 		change_host = (current_thread >= device_threads) ? TRUE : FALSE;
@@ -757,7 +799,13 @@ int main(int argc, char *argv[]) {
 				host_time_double = get_time_as_double();
 			}
 		} else {
-			items_per_thread = 0;
+			snprintf(querybuf, BIG_BUFSIZE, "SELECT SQL_NO_CACHE COUNT(local_data_id) FROM poller_item WHERE host_id=%i AND rrd_next_step <=0", host_id);
+			tresult   = db_query(&mysql, LOCAL, querybuf);
+			mysql_row = mysql_fetch_row(tresult);
+
+			items_per_thread = atoi(mysql_row[0]);
+
+			db_free_result(tresult);
 
 			sprintf(host_time, "%lu", (unsigned long) time(NULL));
 			host_time_double = get_time_as_double();
@@ -883,14 +931,14 @@ int main(int argc, char *argv[]) {
 			thread_status = pthread_create(&threads[device_counter], &attr, child, poller_details);
 
 			if (thread_status == 0) {
-				SPINE_LOG_DEBUG(("DEBUG: Valid Thread to be Created (%ld)", threads[device_counter]));
+				SPINE_LOG_DEBUG(("DEBUG: Device[%i] Valid Thread to be Created (%ld)", poller_details->host_id, (unsigned long int)threads[device_counter]));
 
 				if (change_host) {
 					device_counter++;
 				}
 
 				sem_getvalue(&available_threads, &a_threads_value);
-				SPINE_LOG_MEDIUM(("DEBUG: Available Threads is %i (%i outstanding)", a_threads_value, set.threads - a_threads_value));
+				SPINE_LOG_HIGH(("DEBUG: Device[%i] Available Threads is %i (%i outstanding)", poller_details->host_id, a_threads_value, set.threads - a_threads_value));
 
 				sem_post(&thread_init_sem);
 
@@ -925,11 +973,11 @@ int main(int argc, char *argv[]) {
 		cur_time = get_time_as_double();
 
 		if (cur_time - begin_time > set.poller_interval) {
-			SPINE_LOG(("ERROR: Device[%i] polling timed out while waiting for %d Threads to End", host_id, set.threads - a_threads_value));
+			SPINE_LOG(("ERROR: Polling timed out while waiting for %d Threads to End", set.threads - a_threads_value));
 			break;
 		}
 
-		SPINE_LOG_HIGH(("WARNING: Device[%i] polling sleeping while waiting for %d Threads to End", host_id, set.threads - a_threads_value));
+		SPINE_LOG_HIGH(("NOTE: Polling sleeping while waiting for %d Threads to End", set.threads - a_threads_value));
 		usleep(500000);
 		sem_getvalue(&available_threads, &a_threads_value);
 	}
@@ -938,30 +986,32 @@ int main(int argc, char *argv[]) {
 
 	SPINE_LOG_HIGH(("The final count of Threads is %i", threads_final));
 
-	for (threads_count = 0; threads_count < num_rows; threads_count++) {
+	if (!set.ping_only) {
 		thread_mutex_lock(LOCK_THDET);
 
-		poller_thread_t* det = details[threads_count];
+		for (threads_count = 0; threads_count < num_rows; threads_count++) {
+			poller_thread_t* det = details[threads_count];
 
-		if (threads_missing == -1 && det == NULL) {
-			threads_missing = threads_count;
-		}
+			if (threads_missing == -1 && det == NULL) {
+				threads_missing = threads_count;
+			}
 
-		if (det != NULL) { // && !det->complete) {
-			SPINE_LOG_HIGH(("INFO: Thread %scomplete for Device[%d] and %d to %d sources",
-				det->complete ? "":"in",
-				det->host_id,
-				det->host_data_ids * (det->host_thread - 1),
-				det->host_data_ids * (det->host_thread)));
+			if (det != NULL) { // && !det->complete) {
+				SPINE_LOG_HIGH(("INFO: Device[%i] Thread %scomplete and %d to %d sources",
+					det->host_id,
+					det->complete ? "":"in",
+					det->host_data_ids * (det->host_thread - 1),
+					det->host_data_ids * (det->host_thread)));
 
-			SPINE_LOG_DEVDBG(("DEBUG: DTF: device = %d, host_id = %d, host_thread = %d,"
-				" host_threads = %d, host_data_ids = %d, complete = %d",
-				threads_count,
-				det->host_id,
-				det->host_thread,
-				det->host_threads,
-				det->host_data_ids,
-				det->complete));
+				SPINE_LOG_DEVDBG(("DEBUG: DTF: device = %d, host_id = %d, host_thread = %d,"
+					" host_threads = %d, host_data_ids = %d, complete = %d",
+					threads_count,
+					det->host_id,
+					det->host_thread,
+					det->host_threads,
+					det->host_data_ids,
+					det->complete));
+			}
 		}
 
 		thread_mutex_unlock(LOCK_THDET);
@@ -980,15 +1030,17 @@ int main(int argc, char *argv[]) {
 	}
 
 	/* update the db for |data_time| on graphs */
-	if (set.poller_id == 1) {
-		db_insert(&mysql, LOCAL, "REPLACE INTO settings (name,value) VALUES ('date',NOW())");
-	}
+	if (!set.ping_only) {
+		if (set.poller_id == 1) {
+			db_insert(&mysql, LOCAL, "REPLACE INTO settings (name,value) VALUES ('date',NOW())");
+		}
 
-	snprintf(querybuf, BIG_BUFSIZE, "UPDATE poller_time SET end_time=NOW() WHERE poller_id=%i AND pid=%i", set.poller_id, getpid());
-	if (mode == REMOTE) {
-		db_insert(&mysqlr, REMOTE, querybuf);
-	} else {
-		db_insert(&mysql, LOCAL, querybuf);
+		snprintf(querybuf, BIG_BUFSIZE, "UPDATE poller_time SET end_time=NOW() WHERE poller_id=%i AND pid=%i", set.poller_id, getpid());
+		if (mode == REMOTE) {
+			db_insert(&mysqlr, REMOTE, querybuf);
+		} else {
+			db_insert(&mysql, LOCAL, querybuf);
+		}
 	}
 
 	if (db_pool_local) {
@@ -1005,7 +1057,7 @@ int main(int argc, char *argv[]) {
 	SPINE_LOG_DEBUG(("DEBUG: Thread Cleanup Complete"));
 
 	/* close the php script server */
-	if (set.php_required) {
+	if (set.php_required && !set.ping_only) {
 		php_close(PHP_INIT);
 	}
 
@@ -1050,7 +1102,7 @@ int main(int argc, char *argv[]) {
 	} else {
 		/* provide output if running from command line */
 		if (!set.stdout_notty) {
-			fprintf(stdout,"Time: %.4f s, Threads: %i, Devices: %i\n", (end_time - begin_time), set.threads, num_rows);
+			fprintf(stdout, "Time: %.4f s, Threads: %i, Devices: %i\n", (end_time - begin_time), set.threads, num_rows);
 		}
 	}
 
@@ -1082,6 +1134,7 @@ static void display_help(int only_version) {
 		"  -l/--last=X        End polling with host id X",
 		"  -H/--hostlist=X    Poll the list of host ids, separated by comma's",
 		"  -p/--poller=X      Set the poller id to X",
+		"  -t/--threads=X     Override the database threads setting.",
 		"  -C/--conf=F        Read spine configuration from file F",
 		"  -O/--option=S:V    Override DB settings 'set' with value 'V'",
 		"  -M/--mibs          Refresh the device System Mib data",
@@ -1090,6 +1143,7 @@ static void display_help(int only_version) {
 		"                     The default is 'online'.",
 		"  -R/--readonly      Spine will not write output to the DB",
 		"  -S/--stdout        Logging is performed to standard output",
+		"  -P/--pingonly      Ping device and update device status only",
 		"  -V/--verbosity=V   Set logging verbosity to <V>",
 		"",
 		"Either both of --first/--last must be provided, a valid hostlist must be provided.",
