@@ -352,6 +352,7 @@ typedef struct config_struct {
 	int    active_profiles;
 	int    total_snmp_ports;
 	int    threads;
+	int    threads_set;
 	int    logfile_processed;
 	int    boost_enabled;
 	int    boost_redirect;
@@ -363,6 +364,7 @@ typedef struct config_struct {
 	int    start_host_id;
 	int    end_host_id;
 	char   host_id_list[BIG_BUFSIZE];
+	int    has_device_0;
 	/* database connection information */
 	char   db_host[SMALL_BUFSIZE];
 	char   db_db[SMALL_BUFSIZE];
@@ -399,6 +401,7 @@ typedef struct config_struct {
 	int    ping_timeout;
 	int    ping_failure_count;
 	int    ping_recovery_count;
+	int    ping_only;
 	/* snmp options */
 	int    snmp_max_get_size;
 	int    snmp_retries;
@@ -449,7 +452,7 @@ typedef struct target_struct {
 	char   snmp_password[50];
 	char   snmp_auth_protocol[7];
 	char   snmp_priv_passphrase[200];
-	char   snmp_priv_protocol[7];
+	char   snmp_priv_protocol[8];
 	char   snmp_context[65];
 	char   snmp_engine_id[30];
 	int    snmp_port;
@@ -524,7 +527,7 @@ typedef struct host_struct {
 	char   snmp_password[50];
 	char   snmp_auth_protocol[7];
 	char   snmp_priv_passphrase[200];
-	char   snmp_priv_protocol[7];
+	char   snmp_priv_protocol[8];
 	char   snmp_context[65];
 	char   snmp_engine_id[30];
 	int    snmp_port;
