@@ -372,7 +372,7 @@ void read_config_options() {
 	set.cacti_version = get_cacti_version(&mysql, LOCAL);
 
 	/* log the path_webroot variable */
-	SPINE_LOG_DEBUG(("DEBUG: The binary Cacti version is %s", set.cacti_version));
+	SPINE_LOG_DEBUG(("DEBUG: The binary Cacti version is %d", set.cacti_version));
 
 	/* get logging level from database - overrides spine.conf */
 	if ((res = getsetting(&mysql, LOCAL, "log_verbosity")) != 0) {
@@ -555,11 +555,13 @@ void read_config_options() {
 	SPINE_LOG_DEBUG(("DEBUG: The log_pstats variable is %i", set.log_pstats));
 
 	/* get Cacti defined max threads override spine.conf */
-	if ((res = getpsetting(&mysql, mode, "threads")) != 0) {
-		set.threads = atoi(res);
-		free((char *)res);
-		if (set.threads > MAX_THREADS) {
-			set.threads = MAX_THREADS;
+	if (set.threads_set == FALSE) {
+		if ((res = getpsetting(&mysql, mode, "threads")) != 0) {
+			set.threads = atoi(res);
+			free((char *)res);
+			if (set.threads > MAX_THREADS) {
+				set.threads = MAX_THREADS;
+			}
 		}
 	}
 
@@ -1260,7 +1262,8 @@ int spine_log(const char *format, ...) {
 	fp = stdout;
 
 	/* log message prefix */
-	snprintf(logprefix, SMALL_BUFSIZE, "SPINE: Poller[%i] PID[%i] PT[%ld] ", set.poller_id, getpid(), pthread_self());
+
+	snprintf(logprefix, SMALL_BUFSIZE, "SPINE: Poller[%i] PID[%i] PT[%ld] ", set.poller_id, getpid(), (unsigned long int)pthread_self());
 
 	/* get time for poller_output table */
 	nowbin = time(&nowbin);
